Struct amazon_sp_product_pricing::models::offer_detail::OfferDetail
source · [−]pub struct OfferDetail {Show 16 fields
pub my_offer: Option<bool>,
pub offer_type: Option<OfferCustomerType>,
pub sub_condition: String,
pub seller_id: Option<String>,
pub condition_notes: Option<String>,
pub seller_feedback_rating: Option<Box<SellerFeedbackType>>,
pub shipping_time: Box<DetailedShippingTimeType>,
pub listing_price: Box<MoneyType>,
pub quantity_discount_prices: Option<Vec<QuantityDiscountPriceType>>,
pub points: Option<Box<Points>>,
pub shipping: Box<MoneyType>,
pub ships_from: Option<Box<ShipsFromType>>,
pub is_fulfilled_by_amazon: bool,
pub prime_information: Option<Box<PrimeInformationType>>,
pub is_buy_box_winner: Option<bool>,
pub is_featured_merchant: Option<bool>,
}Fields
my_offer: Option<bool>When true, this is the seller’s offer.
offer_type: Option<OfferCustomerType>sub_condition: StringThe subcondition of the item. Subcondition values: New, Mint, Very Good, Good, Acceptable, Poor, Club, OEM, Warranty, Refurbished Warranty, Refurbished, Open Box, or Other.
seller_id: Option<String>The seller identifier for the offer.
condition_notes: Option<String>Information about the condition of the item.
seller_feedback_rating: Option<Box<SellerFeedbackType>>shipping_time: Box<DetailedShippingTimeType>listing_price: Box<MoneyType>quantity_discount_prices: Option<Vec<QuantityDiscountPriceType>>points: Option<Box<Points>>shipping: Box<MoneyType>ships_from: Option<Box<ShipsFromType>>is_fulfilled_by_amazon: boolWhen true, the offer is fulfilled by Amazon.
prime_information: Option<Box<PrimeInformationType>>is_buy_box_winner: Option<bool>When true, the offer is currently in the Buy Box. There can be up to two Buy Box winners at any time per ASIN, one that is eligible for Prime and one that is not eligible for Prime.
is_featured_merchant: Option<bool>When true, the seller of the item is eligible to win the Buy Box.
Implementations
sourceimpl OfferDetail
impl OfferDetail
pub fn new(
sub_condition: String,
shipping_time: DetailedShippingTimeType,
listing_price: MoneyType,
shipping: MoneyType,
is_fulfilled_by_amazon: bool
) -> OfferDetail